# Proposer - Create Transaction Payload

The proposer is a fiduciary whose responsibility is to make sound financial decisions on behalf of a business and determine where funds are moving from, where to and in which amount. The reasons for sending funds may range across settlement, exchanging, staking and more.

The proposer MUST include the workflow type and all arguments required by a workflow, such as `from_address`, `to_address`, `asset_name`, etc., as well as a UTC datetime representing the time when the transaction is proposed.

The proposer must combine these values into a JSON file, such as:

```json
{
	"workflow": ["cosmos", "withdraw"],
	"values": {
		"delegate_address": "kyve1q9w3nar74up6mxnwd428wpr5nffcw3360tkxer",
		"validator_address": "kyvevaloper1ghpmzfuggm7vcruyhfzrczl4aczy8gas8guslh",
		"asset_name": "KYVE",
		"asset_amount": "0.4",
		"chain_name": "korellia"
	},
	"proposal_datetime": "2025-01-28T18:18:00"
}
```


## Requirements

* [Quorum PGP Key](../operator/quorum-entropy-ceremony.md)

* [Air-Gapped Bundle](../provisioner/air-gapped-bundle.md)

	* The proposer  should print photographic evidence from digital cameras which is stored in a PGP signed repository. The photographs should be of the top and underside of the vacuum sealed object.

	* The proposer should verify the commit signatures of the photographs they are printing against a list of permitted PGP keys found in the "ceremonies" repo

* [Online Machine](TODO)

* Ensure that the computer is configured to sign commits with the desired key. Refer to the [Appendix: Git Commit Signing Configuration](#git-commit-signing-configuration)

* Clone the [Ceremonies Repository](../provisioner/provision-ceremonies-repository.md) for your organization to the machine

## Procedure

1. Turn on online machine 

1. Pull the latest changes from the `ceremonies` repository

1. Unseal the SD Card Pack

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Plug a fresh SD card into the online machine

1. Save the ceremonies repo to the SD card, referred to as the Ceremony SD card

1. Unplug the Ceremony SD card

1. Unseal the tamper proofed bundle

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Insert the AirgapOS SD card into the airgapped machine and turn it on

1. Once booted, unplug the AirgapOS SD card 

1. Plug in the Ceremony SD card

1. Copy the git repo locally from the Ceremony SD card

	* `cp -r /media/external/ceremonies /root/ceremonies; cd /root/ceremonies`

1. Create a new directory in the `ceremonies` repository for the date on which the ceremony for the transaction will take place if it doesn't already exist, for example `2024-01-01/`

	* `mkdir -p keys/ceremonies/2024-01-01/payloads`

1. Determine a new filename `payload_<num>.json`, for example `payload_1.json`

1. Collect data for the transaction being sent, and structure it according to the template below, replacing values with valid ones. The values have to come from a organization approved list of values, for each field, except for `datetime` which is just the current date and time.

	```json
	{
		"workflow": ["<workflow_namespace>", "<workflow_name>"],
		"values": {
			"<workflow_field>": "<workflow_value>"
		},
		"proposal_datetime": "<datetime>"
	}
	```

	Example data object:

	```json
	{
		"workflow": ["cosmos", "withdraw"],
		"values": {
			"delegate_address": "kyve1q9w3nar74up6mxnwd428wpr5nffcw3360tkxer",
			"validator_address": "kyvevaloper1ghpmzfuggm7vcruyhfzrczl4aczy8gas8guslh",
			"asset_name": "KYVE",
			"asset_amount": "0.4",
			"chain_name": "korellia"
		},
		"proposal_datetime": "2025-01-28T18:18:00"
	}
	```

1. Import the keys relevant to the ceremony:

	* `gpg --import keys/all/*.asc`

1. Sign the data in the CLI using `gpg` or another OpenPGP implementation:

	* `gpg --detach-sign <file> <file>.1.sig`

1. Copy the updated ceremonies repo to the SD card

	* `cp -r . /media/external/ceremonies`

1. Unplug the SD card from the air-gapped machine

1. Plug in the SD card into the online machine

1. Create a signed git commit:

	* `git commit -S -m "add <name> pgp key"`

1. Push the latest commit to the repository

1. Notify relevant individuals that there are new transactions queued up, and that a ceremony should be scheduled. This can be automated in the future so that when a commit is made or PR opened, others are notified, for example using a incident management tool.

1. Tamper proof the AirgapOS and Air-gapped laptop

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}

## Appendix

### Git Commit Signing Configuration

{{ #include ../../../../component-documents/git-commit-signing.md:steps }}
